print("""
      Q1_printpattern  Q2_printnostring     Q3_removeduplicate_andsort Q4_recursion
      Q5_copyoddlines  Q6_countwordlinechar Q7_classperson             Q8_rectangle
      Q9_redbus        Q10_phoneno          Q11_validmobno
      Q12_validgmail   Q13_birthday
      
      
      """)